@@ -30,7 +30,7 @@ fn main() {
     `[`[total += `[n]`]`;]`
   }
 
-  `[println!("{:?}", `(total)`);]`
+  `[println!("{:?}", `(total)`)]`;
 }
 "#;
 
@@ -46,7 +46,7 @@ fn main() {
   `[let `(start)` = `[Instant::now()]`;]`
   run_expensive_calculation();
   `[let `[elapsed]` = `[start.elapsed()]`;]`
-  `[println!("Elapsed: {}s", `[elapsed.as_secs()]`);]`
+  `[println!("Elapsed: {}s", `[elapsed.as_secs()]`)]`;
 }
 "#;
 
